@@ -1,8 +1,8 @@
 /*******************************************************
-* Unit:    matrix            release 0.8               *
+* Unit:    matrix            release 0.9               *
 * Purpose: general manipulation with matrices          *
 * Licency: GPL or LGPL                                 *
-* Copyright: (c) 1998-2019 Jaroslav Fojtik             *
+* Copyright: (c) 1998-2021 Jaroslav Fojtik             *
 ********************************************************/
 #include <stdio.h>
 #include <stdlib.h>
@@ -865,10 +865,10 @@ template<class FLOAT>
 temp_matrix<FLOAT> matrix<FLOAT>::triangle(const matrix<FLOAT>& M, int *flips) const
 {
 FLOAT **o;
-register FLOAT **p, **q;
-register FLOAT *l, *r, *s;
-register FLOAT pivot_el,tmp;
-register TSIZE i,j, col,row;
+FLOAT **p, **q;
+FLOAT *l, *r, *s;
+FLOAT pivot_el, tmp;
+TSIZE i,j, col,row;
 
 TSIZE n = size2D;
 TSIZE d = M.size1D;
@@ -940,8 +940,8 @@ return A;
 template<class FLOAT>
 temp_matrix<FLOAT> matrix<FLOAT>::solve(const matrix<FLOAT>& M) const
 {
-register FLOAT **p, **q;
-register FLOAT *l, *r, *s;
+FLOAT **p, **q;
+FLOAT *l, *r, *s;
 
 if (size1D!=size2D || size2D!=M.size2D)
 	{
