@@ -59,6 +59,12 @@ extern "C" {
   #ifndef LO_ENDIAN
    #define LO_ENDIAN
   #endif
+ #else
+  #if (__BYTE_ORDER__==__ORDER_BIG_ENDIAN__)
+   #ifndef HI_ENDIAN
+    #define HI_ENDIAN
+   #endif
+  #endif
  #endif
 
  #if !defined(_ASM_GENERIC_INT_LL64_H) && !defined(_UAPI_ASM_GENERIC_INT_LL64_H)
@@ -280,6 +286,17 @@ void ST_FLOAT_SWAP(void *b, float f);
   #define LD_DOUBLE_HI(ptr)	LD_DOUBLE_SWAP(ptr)
   #define ST_DOUBLE_HI(ptr,val)	ST_DOUBLE_SWAP(ptr,val)
  #endif
+
+ #ifdef HI_ENDIAN
+  #define LD_UINT16_HI(ptr)	LD_UINT16_CPU(ptr)
+  #define LD_UINT32_HI(ptr)	LD_UINT32_CPU(ptr)
+  #define ST_UINT16_HI(ptr,val)	ST_UINT16_CPU(ptr,val)
+  #define ST_UINT32_HI(ptr,val)	ST_UINT32_CPU(ptr,val)
+  #if defined(__u64_defined)
+   #define LD_UINT64_HI(ptr)	LD_UINT64_CPU(ptr)
+   #define ST_UINT64_HI(ptr,val) ST_UINT64_CPU(ptr,val)
+  #endif
+ #endif
 #endif
 
 
