@@ -1,3 +1,9 @@
+/*************************************************************************
+* unit:    UTF8
+*   utf8.c  - Provides helpers for manipulation with UTF8.
+* Licency: GPL or LGPL                                                   *
+*   Copyright (C) 1999-2021  Jaroslav Fojtik
+**************************************************************************/
 #include <stdio.h>
 
 #include "typedfs.h"
@@ -10,7 +16,7 @@ DWORD utf8_fgetc(FILE *F);
 #endif
 
 
-/* number of following bytes in sequence based on first byte value (for bytes above 0x7f) */
+/** Number of following bytes in sequence based on first byte value (for bytes above 0x7f) */
 static const BYTE utf8_length[128] =
 {
     0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x80-0x8f */
@@ -23,14 +29,16 @@ static const BYTE utf8_length[128] =
     3,3,3,3,3,3,3,3,4,4,4,4,5,5,0,0  /* 0xf0-0xff */
 };
 
-/* first byte mask depending on UTF-8 sequence length */
+/** first byte mask depending on UTF-8 sequence length */
 static const unsigned char utf8_mask[6] = { 0x7f, 0x1f, 0x0f, 0x07, 0x03, 0x01 };
 
 
+/** Read one UTF8 character from a file. */
 DWORD utf8_fgetc(FILE *F)
 {
-BYTE buffer[7],*b;
+BYTE buffer[7];
 BYTE len;
+BYTE *b;
 DWORD d;
 
  d = fgetc(F);
@@ -39,14 +47,14 @@ DWORD d;
 
  len = utf8_length[d-0x80];
  if(len==0) return(0xFFFFFFFF);
- d=d & utf8_mask[len];
- fread(buffer,len,1,F);
- buffer[len]=0;
- b=buffer;
+ d &= utf8_mask[len];
+ if(fread(buffer,len,1,F) != 1) return(0xFFFFFFFF);
+ buffer[len] = 0;
+ b = buffer;
  while(*b>0)
    {
-   if( (*b=*b ^ 0x80) >= 0x40 ) return(0xFFFFFFFF); //error
-   d=(d<<6) | *b;
+   if((*b=*b ^ 0x80) >= 0x40) return(0xFFFFFFFF); //error
+   d = (d<<6) | *b;
    b++;
    }
  return(d);
