@@ -233,7 +233,7 @@ return;
 }
 
 
-void LoadCodePage(string cpfilename, codepage & cp, int ShowAll=1)
+bool LoadCodePage(string cpfilename, codepage & cp, int ShowAll=1)
 {
 FILE *Fcp;
 
@@ -245,13 +245,14 @@ FILE *Fcp;
  if((Fcp=fopen(cpfilename,"r"))==NULL )
 	{
 	printf("\nError: cannot open file:%s!!!",cpfilename());
-	return;
+	return false;
 	}
 
  while(!feof(Fcp))
 	ReadChar(Fcp,cp);
 
  fclose(Fcp);
+ return true;
 }
 
 
