@@ -94,7 +94,8 @@ while(!feof(f))
                  (line[i]!='\\')|| (line[i]!=':')) temp+=line[i];
                                               else break;
            }
-  if(!temp.isEmpty()) putenv(temp.ExtractString()); //The string must not be released!!!
+  if(!temp.isEmpty())
+    putenv(temp.ExtractString()); //The string must not be released!!!
 //puts(temp.ch);
   }
 fclose(f);
@@ -171,8 +172,19 @@ static const char GET_LOCALE_INFO[] = "";
 	  }
      bindtextdomain(GtxtDomain, ProgPath());
 
-     Empty2Info = _(GET_LOCALE_INFO);	//when gettext is active "" is expanded to the localisation details    
+     Empty2Info = _(GET_LOCALE_INFO);	//when gettext is active "" is expanded to the localisation details 
      }
+
+#ifdef _MSC_VER
+  if(Empty2Info!=NULL && *Empty2Info!=0)
+  {
+    //printf("%s",Empty2Info);
+    if(strstr(Empty2Info,"charset=UTF-8")!=NULL)
+    {
+      FixConsole2UTF8();
+    }
+  }
+#endif
 }
 
 
