@@ -2,14 +2,15 @@
 #define __IMAGES_H__
 
 
-#define WPGu2PSu(x) ( (float)(x)*71/(25.4*47.0) )
-#define PSu2WPGu(x) ( (float)(x)*(25.4*47.0)/71.0 )
-#define WPGu2mm(x) ( (float)(x)*71/(7.91*25.4*47.0) )
+// 1 point (Postscript) = 0.3527777778 mm = 1/72 inch.
+// 1 m equals 2660 pt
+// [WPGu] = [inch] / 1200
 
+#define WPGu2PSu(x) ( (float)(x)*71/(25.4f*47.0f) )
+#define PSu2WPGu(x) ( (float)(x)*(25.4f*47.0f)/(71.0f) )
+#define WPGu2mm(x) ( (float)(x)*71*2.66f/(7.91f*25.4f*47.0f) )
+#define mm2WPGu(x) ( (float)(x)*7.91f*25.4f*47.0f / (71.0f*2.66f) )
 
-void StoreText2PS(string & PSData, string & Text, PS_State *PSS, WORD RotAngle,
-		float UpRightX, float UpRightY, float LowLeftX, float LowLeftY,
-		float FontSize);
 
 class TconvertedPass1;
 class AbstractTransformXY;
