@@ -51,22 +51,104 @@ METHODDEF(void) my_error_exit (j_common_ptr cinfo)
 
 
 #if SupportJPG>=4 || SupportJPG==2
+
+Raster2DAbstract *LoadFragmentJPG(FILE *F)
+{
+struct jpeg_decompress_struct cinfo;
+struct my_error_mgr jerr;
+int row_stride;		/* physical row width in output buffer */
+JSAMPARRAY buffer;	/* Output row buffer */
+unsigned current_line = 0;
+
+  if(F==NULL) return NULL;
+
+	/* Step 1: allocate and initialize JPEG decompression object */
+
+  cinfo.err = jpeg_std_error(&jerr.pub);
+  jerr.pub.error_exit = my_error_exit;
+  /* Establish the setjmp return context for my_error_exit to use. */
+  if(setjmp(jerr.setjmp_buffer))
+     { /* If we get here, the JPEG code has signaled an error. We need to clean up the JPEG object, close the input file, and return. */
+     jpeg_destroy_decompress(&cinfo);
+     return NULL;
+     }
+  
+  jpeg_create_decompress(&cinfo);	/* Now we can initialize the JPEG decompression object. */
+
+	/* Step 2: specify data source (eg, a file) */
+  jpeg_stdio_src(&cinfo, F);
+
+	/* Step 3: read file parameters with jpeg_read_header() */
+
+  (void) jpeg_read_header(&cinfo, TRUE);
+  /* We can ignore the return value from jpeg_read_header since
+   *   (a) suspension is not possible with the stdio data source, and
+   *   (b) we passed TRUE to reject a tables-only JPEG file as an error.
+   * See libjpeg.doc for more info. */
+
+   Raster2DAbstract *Raster = CreateRaster2D(cinfo.image_width,cinfo.image_height,24);
+   if(Raster==NULL) return NULL;
+
+	/* Step 5: Start decompressor */
+  (void)jpeg_start_decompress(&cinfo);
+
+  row_stride = cinfo.output_width * cinfo.output_components;
+  /* Make a one-row-high sample array that will go away when done with image */
+  buffer = (*cinfo.mem->alloc_sarray)((j_common_ptr) &cinfo, JPOOL_IMAGE, row_stride, 1);
+
+	/* Step 6: while (scan lines remain to be read) */
+	/*           jpeg_read_scanlines(...); */
+
+  /* Here we use the library's state variable cinfo.output_scanline as the
+   * loop counter, so that we don't have to keep track ourselves. */
+  while(cinfo.output_scanline < cinfo.output_height)
+    { /* jpeg_read_scanlines expects an array of pointers to scanlines.
+       * Here the array is only one element long, but you could ask for
+       * more than one scanline at a time if that's more convenient. */
+    (void)jpeg_read_scanlines(&cinfo, buffer, 1);
+    
+    int line_size = 3 * cinfo.output_width;	    /* Assume put_scanline_someplace wants a pointer and sample count. */
+
+    //{     BlockWrite(outfile, buffer^, row_stride);}
+
+    if(line_size > row_stride) line_size = row_stride;
+
+    if(current_line < Raster->Size2D)
+		memcpy(Raster->GetRow(current_line), buffer[0], line_size);
+    current_line++;
+
+    //if AlineProc<>nil then AlineProc^.NextLine;
+
+    //put_scanline_someplace(buffer[0], row_stride);
+    }
+
+	/* Step 7: Finish decompression */
+
+  (void)jpeg_finish_decompress(&cinfo);
+  /* We can ignore the return value since suspension is not possible with the stdio data source. */
+
+	/* Step 8: Release JPEG decompression object */
+	/* This is an important step since it will release a good deal of memory. */
+  jpeg_destroy_decompress(&cinfo);
+
+return Raster;
+}
+
+
 Image LoadPictureJPG(const char *Name)
 {
 Image Img;
-int line_size;
 unsigned current_line = 0;
     /* This struct contains the JPEG decompression parameters and pointers to
      * working space (which is allocated as needed by the JPEG library). */
 struct jpeg_decompress_struct cinfo;
   /* We use our private extension JPEG error handler.
    * Note that this struct must live as long as the main JPEG parameter
-   * struct, to avoid dangling-pointer problems.
-   */
+   * struct, to avoid dangling-pointer problems. */
 struct my_error_mgr jerr;
   /* More stuff */
 FILE * infile;		/* source file */
-JSAMPARRAY buffer;		/* Output row buffer */
+JSAMPARRAY buffer;	/* Output row buffer */
 int row_stride;		/* physical row width in output buffer */
 
   /* In this example we want to open the input file before doing anything else,
@@ -129,8 +211,7 @@ int row_stride;		/* physical row width in output buffer */
   /* JSAMPLEs per row in output buffer */
   row_stride = cinfo.output_width * cinfo.output_components;
   /* Make a one-row-high sample array that will go away when done with image */
-  buffer = (*cinfo.mem->alloc_sarray)
-		((j_common_ptr) &cinfo, JPOOL_IMAGE, row_stride, 1);
+  buffer = (*cinfo.mem->alloc_sarray)((j_common_ptr) &cinfo, JPOOL_IMAGE, row_stride, 1);
 
   /* Step 6: while (scan lines remain to be read) */
   /*           jpeg_read_scanlines(...); */
@@ -144,7 +225,7 @@ int row_stride;		/* physical row width in output buffer */
     (void) jpeg_read_scanlines(&cinfo, buffer, 1);
     
     /* Assume put_scanline_someplace wants a pointer and sample count. */
-    line_size = 3 * cinfo.output_width;
+    int line_size = 3 * cinfo.output_width;
 
     //{     BlockWrite(outfile, buffer^, row_stride);}
 
