@@ -1,5 +1,5 @@
 /******************************************************************************
- * Unit:    raster            release 0.18                                    *
+ * Unit:    raster            release 0.21                                    *
  * Prototype declaration of separate classes. Normally this is not needed     *
  * to be included.                                                            *
  * licency:     GPL or LGPL                                                   *
@@ -164,15 +164,19 @@ class Raster1D_64Bit:virtual public Raster1DAbstract
 	{
 public: virtual int GetPlanes(void) const {return(64);};
 
-	virtual DWORD GetValue1D(unsigned x) const {if(x<Size1D) return((DWORD)((QWORD *)Data1D)[x]); return(0);};
+	virtual DWORD GetValue1D(unsigned x) const;
 	virtual double GetValue1Dd(unsigned x) const {if(x<Size1D) return((double)((QWORD *)Data1D)[x]); return(0);};
-	virtual void SetValue1D(unsigned x, DWORD NewValue) {if(x<Size1D) ((QWORD *)Data1D)[x]=NewValue; return;};
+	virtual void SetValue1D(unsigned x, DWORD NewValue);
 	virtual void SetValue1Dd(unsigned x, double NewValue);
 #ifdef _REENTRANT
         virtual DWORD PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const;
         virtual double PTR_GetValue1Dd(const void *RAW_Data1D, unsigned x) const;
         virtual void PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const;
         virtual void PTR_SetValue1Dd(void *RAW_Data1D, unsigned x, double NewValue) const;
+#endif
+#ifdef OPTIMISE_SPEED
+	//virtual void Get(Raster1DAbstract &R1) const;
+	virtual void Set(const Raster1DAbstract &R1);
 #endif
 	};
 #endif
