@@ -1,5 +1,5 @@
 /***************************************************************************
- * Unit:    raster            release 0.20                                 *
+ * Unit:    raster            release 0.21                                 *
  * Purpose: Prototypes for general manipulation n dimensional matrices     *
  * Modul:   raster.cc                                                      *
  * Licency: GPL or LGPL                                                    *
@@ -10,7 +10,7 @@
 
 #include "typedfs.h"
 
-#define RASTER_VERSION (0x100*0 | 20)
+#define RASTER_VERSION (0x100*0 | 21)
 
 #ifndef No_Memory
  #define No_Memory    0x1
@@ -49,6 +49,7 @@
 extern "C" {
 #endif
 
+void Conv1_4(BYTE *Dest, const BYTE *Src, unsigned Size1D);
 void Conv1_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
 void Conv1_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
 void Conv1_24(BYTE *Dest, const BYTE *Src, unsigned Size1D);
@@ -65,16 +66,22 @@ void Conv8_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
 void Conv16_1(BYTE *Dest, const WORD *Src, unsigned Size1D);
 void Conv16_4(BYTE *Dest, const WORD *Src, unsigned Size1D);
 void Conv16_8(BYTE *Dest, const WORD *Src, unsigned Size1D);
+void Conv16_24(BYTE *Dest, const WORD *Src, unsigned Size1D);
 void Conv16_32(DWORD *Dest, const WORD *Src, unsigned Size1D);
 void Conv24_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
+void Conv24_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
+void Conv24_32(DWORD *Dest, const BYTE *Src, unsigned Size1D);
 void Conv32_1(BYTE *Dest, const DWORD *Src, unsigned Size1D);
 void Conv32_4(BYTE *Dest, const DWORD *Src, unsigned Size1D);
 void Conv32_8(BYTE *Dest, const DWORD *Src, unsigned Size1D);
 void Conv32_16(WORD *Dest, const DWORD *Src, unsigned Size1D);
+void Conv32_24(BYTE *Dest, const DWORD *Src, unsigned Size1D);
 
 #ifdef QWORD
 void Conv1_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
 void Conv8_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
+void Conv24_64(QWORD *Dest, const BYTE *Src, unsigned Size1D);
+void Conv32_64(QWORD *Dest, const DWORD *Src, unsigned Size1D);
 #endif
 
 
@@ -395,7 +402,8 @@ struct RGB_Record
 
 class APalette: virtual public Raster1DAbstractRGB
 	{
-public: virtual void Get(unsigned index, RGBQuad *RGB);
+public: virtual void Get(unsigned index, RGBQuad *RGB) const;
+        virtual void Set(unsigned index, const RGBQuad *RGB);
 	friend APalette *BuildPalette(unsigned Indices, char type);
 	};
 APalette *BuildPalette(unsigned Indices, char type=0);
