@@ -389,6 +389,45 @@ void VectorEllipse::Transform(const AbstractTransformXY &Tx)
 }
 
 
+temp_string VectorPie::Export2EPS(PS_State *PSS) const
+{
+string str;
+
+  if(PSS != NULL)
+  {
+    vecPen::prepExport(PSS);    
+    vecBrush::prepExport(PSS);
+    PS_Attr(str,PSS);
+  }
+
+  bool ContextSaved = false;
+  if(Tx) 
+    ContextSaved = Tx->ApplyTransform(str);
+
+  str.cat_printf("\nnewpath"
+		 "\n%2.2f %2.2f moveto", (RightRect+LeftRect)/2, (TopRect+BottomRect)/2);
+  str.cat_printf("\n%2.2f %2.2f %2.2f %2.2f %d %d DrawEllipse"
+	         "\nclosepath",
+			 (RightRect+LeftRect)/2, (TopRect+BottomRect)/2,
+			 fabs(RightRect-LeftRect)/2, fabs(TopRect-BottomRect)/2,
+			 bAngle, eAngle);
+  //str.cat_printf("\n%2.2f %2.2f lineto", (RightRect+LeftRect)/2, (TopRect+BottomRect)/2);
+
+  if(BrushStyle!=0)
+  {
+    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
+  }
+  else
+  {    
+    str += "\nstroke";
+  }
+
+  if(ContextSaved) str += "\ngrestore";
+
+return temp_string(str);
+}
+
+
 
 /////////////////////////////////////////////////////////////
 
