@@ -255,6 +255,15 @@ public:
 };
 
 
+class VectorPie: public VectorEllipse
+{
+public:
+  VectorPie(float iniBottomRect, float iniTopRect, float iniRightRect, float iniLeftRect): VectorEllipse(iniBottomRect,iniTopRect,iniRightRect,iniLeftRect) {}
+
+  virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
+};
+
+
 class VectorLine: public VectorObject, public vecPen
 {
 public:
