@@ -1865,12 +1865,12 @@ const char *FontTblItem;
    TexFontName="WP:"+TexFontName;
    for(i=0;i<length(FontTable);i++)	//Try to find LaTeX equivalent of WP font
 	{
-	if( (FontTblItem=FontTable[i])==NULL ) continue;
+	if((FontTblItem=FontTable[i]) == NULL) continue;
 	if(strstr(FontTblItem,TexFontName())!=NULL)
 		{
-		if( (FontTblItem=strstr(FontTblItem,"TeX:"))==NULL ) continue;
+		if((FontTblItem=strstr(FontTblItem,"TeX:"))==NULL) continue;
 		if(*FontTblItem==0) continue;
-		TexFontName=FontTblItem+4;
+		TexFontName = FontTblItem+4;
 		goto Found;
 		}
 	}
@@ -1878,23 +1878,34 @@ const char *FontTblItem;
    }
 
 Found:
+  cq->NativeCpg = NULL;
+  i = 0;
   if(NFSS)
-    {
-    i=0;
+    {    
     Close_All_Attr(cq->attr,cq->strip);
     if(PointSize>0)
 	{
-	fprintf(cq->strip, "\\fontsize{%2.1f}{%2.1f}",float(PointSize)/50,float(PointSize+50)/50);
-	i=1;
+	fprintf(cq->strip, "\\fontsize{%2.1f}{%2.1f}", float(PointSize)/50, float(PointSize+50)/50);
+	i = 1;
 	}
     if(FontName != NULL)
+      {
       if(!TexFontName.isEmpty())
 	{
 	fprintf(cq->strip,"\\fontshape{%s}",TexFontName());
-	i|=2;
-	}
+	i |= 2;
+	}      
+      }
     if(i>0) fprintf(cq->strip,"\\selectfont ");
     }
+
+  if((i&2) == 0)
+    {
+    if(FontName!=NULL && !strncmp(FontName,"Wingdings",9))
+      {
+        cq->NativeCpg = GetTranslator("WingdingsTOinternal");
+      }
+    }
 }
 
 
@@ -2431,7 +2442,7 @@ if(type==6)
 ///////////////////////////////////////////
 
 
-void TconvertedPass1::InitMe(FILE *FileIn, FILE *Table, FILE *StripOut, FILE *LogFile,FILE *ErrorFile)
+void TconvertedPass1::InitMe(FILE *FileIn, FILE *Table, FILE *StripOut, FILE *LogFile, FILE *ErrorFile)
 {
   attr.InitAttr();
 
