@@ -81,7 +81,7 @@ string translator;
      case 2:translator="koi8cs";break;	//koi8cs
      default:cq->ConvertCpg = NULL;
      }
-if(translator!="")
+  if(!translator.isEmpty())
      {
      translator+="TOinternal";
      cq->ConvertCpg = GetTranslator(translator);
