@@ -175,7 +175,7 @@ attribute NewAttr;
      }
 
   AttrFit(attr,NewAttr,s);
-  if(s!="") fputs(s(),strip);
+  if(!s.isEmpty()) fputs(s(),strip);
 
 return;
 }
@@ -589,7 +589,7 @@ const char *tag = NULL;
 BYTE by, subby;
 
  *ObjType = 0;
- if(TAG=="") ReadXMLTag();
+ if(TAG.isEmpty()) ReadXMLTag();
  by = this->by;
  subby = this->subby;
 
@@ -605,7 +605,7 @@ BYTE by, subby;
 	       }
              break;
 	case XML_extchar:
-             if(TAG=="") break;			//Extended chatacter &xxx;
+             if(TAG.isEmpty()) break;			//Extended chatacter &xxx;
 	       TAG = Ext_chr_str(TAG[0],this) + copy(TAG,1,length(TAG)-1);
 	       tag=TAG();
 	       by=201;
@@ -641,7 +641,7 @@ BYTE by, subby;
 	case XML_comment:			//comment
 	       break;
 	case XML_badextchar:
-               if(TAG=="") break;		//Extended chatacter &xxx
+               if(TAG.isEmpty()) break;		//Extended chatacter &xxx
 	       TAG[length(TAG)-1] = ' ';
 	       TAG=Ext_chr_str(TAG[0],this) + copy(TAG,1,length(TAG)-1);
 	       tag = TAG();
