@@ -26,7 +26,7 @@
 
 list HTMLChars(Table_html,sizeof(Table_html)/sizeof(char *));
 
-#define HTMLVersion "0.28"
+#define HTMLVersion "0.29"
 
 
 /** Base class for HTML document conversion. */
@@ -670,7 +670,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
  int i;
 
  *ObjType = 0;
- if(this->TAG=="") ReadXMLTag();
+ if(this->TAG.isEmpty()) ReadXMLTag();
  by = this->by;
  subby = this->subby;
 
