@@ -86,7 +86,7 @@ typedef struct save	// property save structure
     BYTE Cols;		// Number of columns inside current block
     bool fSkipDestIfUnk;
 
-    CpTranslator *ConvertCpg; //Code page related to a current font selected
+    const CpTranslator *ConvertCpg; //Code page related to a current font selected
 } SAVE;
 
 // What types of properties are there?
