@@ -682,13 +682,13 @@ bool TconvertedPass2::OpenEnvironment(void)
 	     break;
 
     case 'I':
-    case 'i':if(Lines[cur].Lstring=="")  //indent nothing ??
+    case 'i':if(Lines[cur].Lstring.isEmpty())  //indent nothing ??
 		 {
 		 return true;		// Signalise special handling to the caller.
                  }
 	     if((Lines[cur].Indent_Level<2)||(toupper(Lines[pre].envir)!='I'))
 		 {
-		 if(Lines[pre].Lstring!="")
+		 if(!Lines[pre].Lstring.isEmpty())
 			   fprintf(LaTeX,"\\testlastline\n\n");
                  else fprintf(LaTeX,"\\zerotestlastline\n");
                  }
@@ -827,9 +827,10 @@ int r;
       if(r==0)
         {
         *str2=' ';
-        strcpy(str,str+optlen);		// Overlapping regions
-        //i = strlen(aline) - optlen;
-        //memmove(str,str+7,strlen(str+7));str[i]=0; // Overlapping regions, but terminating 0 must be added for memmove.	
+        //strcpy(str,str+optlen);		// Overlapping regions, strcpy is dangerous
+        const unsigned B2Move = strlen(str+optlen);
+        memmove(str,str+optlen,B2Move);
+        str[B2Move]=0; // Overlapping regions, but terminating 0 must be added for memmove.
 	return true;
 	}
       else r--;
@@ -874,7 +875,7 @@ int i;
 
 static int FixBracket(string & Line)
 {
-  if (Line == "") return 0;
+  if(Line.isEmpty()) return 0;
 
   Line="{}"+Line;
 
@@ -1456,12 +1457,12 @@ Reject:	if(OldChar!='\\')
 /** fix occurence \/ in the vertical mode - remove it */
 void TconvertedPass2::FixItallicAlignment(string *aLineStr)
 {
-  if( (Lines[pre].Lstring=="")&&(length(*aLineStr)>=2) )
+  if( (Lines[pre].Lstring.isEmpty())&&(length(*aLineStr)>=2) )
     if (  (*aLineStr)[0]=='\\' &&  (*aLineStr)[1]=='/' )
 	*aLineStr=copy(*aLineStr,2,length(*aLineStr)-2);
 
   if( (length(Lines[next].Lstring)>=2) &&
-     (*aLineStr=="" ||
+     (aLineStr->isEmpty() ||
        Lines[cur].line_term=='h' || Lines[cur].line_term=='p') )
     if( (Lines[next].Lstring)[0]=='\\' &&  (Lines[next].Lstring)[1]=='/' )
 	Lines[next].Lstring=copy(Lines[next].Lstring,2,length(Lines[next].Lstring)-2);
@@ -1510,7 +1511,7 @@ MatchAgain:
     NextLine->Lstring = copy(NextLine->Lstring,strlen(CHelpS),length(NextLine->Lstring)-strlen(CHelpS));
 
 		// and append it to a current line    
-    if(CurLine->Lstring=="" && Lines[pre].Lstring!="")
+    if(CurLine->Lstring.isEmpty() && !Lines[pre].Lstring.isEmpty())
         {	// When a current line is empty, add \n	
 	CurLine->Lstring += CHelpS;
 	CurLine->Lstring += "\n";
@@ -1601,7 +1602,7 @@ TconvertedPass2 cq2;
   cq2.Lines[cq2.next2].Empty = EmptyLine(cq2.Lines[cq2.next2].Lstring);
 
 
-  while((!feof(Strip) || cq2.Lines[cq2.cur].Lstring!="" || cq2.Lines[cq2.next].Lstring!="" || cq2.Lines[cq2.next2].Lstring!=""))
+  while((!feof(Strip) || !cq2.Lines[cq2.cur].Lstring.isEmpty() || !cq2.Lines[cq2.next].Lstring.isEmpty() || !cq2.Lines[cq2.next2].Lstring.isEmpty()))
      {
      cq2.Update_global_information();     
 
@@ -1750,7 +1751,7 @@ TconvertedPass2 cq2;
 	/* Some optimizations of text on current line */
 
 			//fix beginning paragraph with \raise command
-    if(cq2.Lines[cq2.pre].Lstring=="" && length(*aLineStr)>=6)
+    if(cq2.Lines[cq2.pre].Lstring.isEmpty() && length(*aLineStr)>=6)
 	{
 	if(!strncmp((*aLineStr),"\\raise",6))
 		*aLineStr="\\strut"+*aLineStr;
@@ -1787,7 +1788,7 @@ TconvertedPass2 cq2;
 
 		//fix closed attributes problem
     if(cq2.Lines[cq2.cur].attr.ClosedAttr()) /* Are attributes closed? */
-      if(*aLineStr == "")
+      if(aLineStr->isEmpty())
 	 {
 	 if(cq2.Lines[cq2.next].attr.Closed_Depth==cq2.Lines[cq2.cur].attr.Closed_Depth)
 		{
@@ -1806,9 +1807,9 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
          }
 
 
-  if(*aLineStr!="" || cq2.Lines[cq2.next].envir=='!')
+  if(!aLineStr->isEmpty() || cq2.Lines[cq2.next].envir=='!')
 	 {		/* Attributes are closed */
-	 if(cq2.Lines[cq2.cur].LineFlag & 1  && (*aLineStr == '%'||*aLineStr == ""))
+	 if(cq2.Lines[cq2.cur].LineFlag & 1  && (aLineStr->isEmpty()||*aLineStr=='%'))
 		 {
 		 if(cq2.Change_envir_EOL())
 		   cq2.CloseEnvironment();
@@ -1884,7 +1885,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 		   if (cq2.Lines[cq2.next].attr.Opened_Depth>0) /* Attributes are opened */
 		     {
 		     Close_All_Attr(cq2.Lines[cq2.next].attr,s); /* close attributes on EOL */
-		     if((cq2.Lines[cq2.pre].Lstring=="") && cq2.Lines[cq2.cur].Empty)
+		     if((cq2.Lines[cq2.pre].Lstring.isEmpty()) && cq2.Lines[cq2.cur].Empty)
 			s = replacesubstring(s,"\\/","");  //remove \/ in vertical mode
 		     fputs(s(),cq2.LaTeX);
 		     }
@@ -1933,23 +1934,23 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
 			}
 		    else {
 			 if(cq2.Lines[cq2.next].envir=='^'); // do not solve anything at the end of the minipage
-			 else if (*aLineStr == "" &&
-				cq2.Lines[cq2.pre].Lstring == "")
+			 else if(aLineStr->isEmpty() &&
+				cq2.Lines[cq2.pre].Lstring.isEmpty())
 				   {
 				   fprintf(cq2.LaTeX, "\\bigskip");
 				   }
-			 else if (cq2.Lines[cq2.next].Empty>0)
+			 else if(cq2.Lines[cq2.next].Empty>0)
 				{
 				cq2.Lines[cq2.next].InhibitBsBslash = true;
 				}
-			 else if (!cq2.Lines[cq2.cur].InhibitBsBslash)
+			 else if(!cq2.Lines[cq2.cur].InhibitBsBslash)
 				{
 /*				if (!cq2.just_envir_closed && (cq2.Lines[cq2.cur].envir=='L' || cq2.Lines[cq2.cur].envir=='R'))
 					 fprintf(cq2.LaTeX, "\\nwln");
 				   else*/ {
 					if(cq2.Lines[cq2.cur].Empty>0)
 						 {
-						 if(cq2.Lines[cq2.pre].Lstring!="")
+						 if(!cq2.Lines[cq2.pre].Lstring.isEmpty())
 							fputc('\n',cq2.LaTeX);
 						 fprintf(cq2.LaTeX, " \\bigskip");
 						 }
@@ -1969,7 +1970,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
     case 'P':if(cq2.Lines[cq2.next].attr.Opened_Depth>0) /* Attributes are opened */
 		     {
 		     Close_All_Attr(cq2.Lines[cq2.next].attr,s); /* close attributes on EOL */
-		     if((cq2.Lines[cq2.pre].Lstring=="") && cq2.Lines[cq2.cur].Empty)
+		     if((cq2.Lines[cq2.pre].Lstring.isEmpty()) && cq2.Lines[cq2.cur].Empty)
 			s = replacesubstring(s,"\\/","");  //remove \/ in vertical mode
 		     fputs(s(),cq2.LaTeX);
 		     }
