@@ -1318,7 +1318,7 @@ long j;
   cq->envir=' ';
   cq->rownum=0;
 
-  cq->ConvertCpg=NULL;
+  cq->NativeCpg = cq->ConvertCpg = NULL;
 }
 
 #undef L1_5cm
@@ -1523,7 +1523,7 @@ int p;
 	  
 	  if(!strcmp(name, "Styles") || !strcmp(name, "styles"))
 	     {
-	     CPStyles=true;
+	     CPStyles = true;
 	     continue;
 	     }
 	  OutCodePage = 0;
