@@ -318,7 +318,7 @@ static bool printed=false;
 
  if(Verbosing < 1) return;
  printf(_("\n>>>WP2LaTeX<<< Conversion program: From Wordperfect to LaTeX Version %s \n"
-	  "  (c) Made by J.Fojtik  ---- Date : 1996-2021\n"),
+	  "  (c) Made by J.Fojtik  ---- Date : 1996-2022\n"),
 	    VersionWP2L);
 }
 
@@ -349,8 +349,8 @@ void ShowHelp(void)
 	  "\n         \"852\"(ISO8), \"866\"(Russ), \"895\"(Kamenicky), \"1250\"(Win),"
 	  "\n         \"1251\"(WinRuss), \"ISO8859_1\", \"ISO8859-2\", \"KOI8R\", \"UTF8\"."
 	  "\n   -cp-styles   Turn on special styles for codepages."
-	  "\n   -CurrentFontSet  Change codepage for a current font."
-	  "\n               \"Magical\" WP's codepage 12."
+	  "\n   -CurrentFontSet  codepage    Change codepage for a current font."
+	  "\n               \"Magical\" WP's codepage 12. Same argunents as -cp-"
 	  "\n   -epsfig      %cUse style epsfig.sty for PostScript images."
 	  "\n   -extract-images %sImages will be extracted into separate files."
 	  "\n   -fancyhdr    Use package fancyhdr.sty for headers and footers"
